--[[
Textured sphere renderer, by retrotails.
Textures from http://orsa.sourceforge.net/download.html
]]--
function love.load()
    planet = {
        rot = 0,
        tex = love.graphics.newImage('earth.png'),
        shade = love.graphics.newImage('shade.png'),
        cd = 0,
        day = 0,
        name = 'earth'
    }
    planet.w = planet.tex:getWidth()
    planet.h = planet.tex:getHeight()
    planet.w2 = planet.w/512
    planet.h2 = planet.h/512
    screen = {
        w = love.graphics.getWidth(),
        h = love.graphics.getHeight(),
    }
end
function love.update(dt2)
    dt = dt2
    if love.keyboard.isDown('escape') then
        love.event.quit()
    elseif love.keyboard.isDown('left') then
        planet.rot = planet.rot + dt * 128
        planet.cd = 2
    elseif love.keyboard.isDown('right') then
        planet.rot = planet.rot - dt * 128
        planet.cd = 2
    elseif love.keyboard.isDown('up') then
        planet.day = planet.day + .5 * dt
    elseif love.keyboard.isDown('down') then
        planet.day = planet.day - .5 * dt
    end
    if planet.cd <= 0 then
        planet.cd = 0
        planet.rot = planet.rot + dt * 64
    else
        planet.cd = planet.cd - dt
        if planet.cd <= 1 then
            planet.rot = planet.rot + (dt * 64) * (1 - planet.cd)
        end
    end
    if planet.rot >= 512 then
        planet.rot = planet.rot - 512
    elseif planet.rot <= 0 then
        planet.rot = planet.rot + 512
    end
    if planet.day > 3 then
        planet.day = planet.day - 4
    elseif planet.day < -1 then
        planet.day = planet.day + 4
    end
end
function love.draw()
    
    for i = 0,screen.w - 1,1 do
        scale = math.cos((math.abs((i - 128)/128))^(math.pi/2))/(math.pi/2)
        love.graphics.setScissor(i, 0, 1, screen.h)
        love.graphics.draw(planet.tex, screen.w/2, screen.h/2, 0, scale/planet.h2, 1/planet.w2, planet.rot*(planet.w2) + planet.w/2, planet.h/2)
        love.graphics.draw(planet.tex, screen.w/2, screen.h/2, 0, scale/planet.h2, 1/planet.w2, planet.rot*(planet.w2) - planet.w/2, planet.h/2)
    end
    planet.canvas = love.graphics.newImage(love.graphics.newScreenshot())
    --Draws texture lixe its on a tube
    
    for i = 0,screen.h - 1,1 do
        scale = math.acos((math.abs((i - 128)/128))^2)/(math.pi/2)
        love.graphics.setScissor(screen.w * (1 - scale)/2,i,screen.w * (scale), 1)
        love.graphics.draw(planet.canvas, screen.w/2 - 1, screen.h/2, 0, scale, 1, 128, 128)
    end
    --Turns it into a sphere
    
    love.graphics.setColor(0,0,0,128)
    for i = 0,screen.h - 1,1 do
        scale = math.acos((math.abs((i - 128)/128))^2)/(math.pi/2)
        love.graphics.setScissor(screen.w * (1 - scale)/2,i,screen.w * (scale), 1)
        love.graphics.rectangle('fill', screen.w * (1 - scale * planet.day)/2, i, screen.w * (scale), 1)
    end
    love.graphics.setColor(255,255,255,255)
    love.graphics.setScissor()
    --Renders shadow
    
    love.graphics.setBlendMode('multiplicative')
    love.graphics.draw(planet.shade, 0, 0)
    love.graphics.setBlendMode('alpha')
    --Draws shadow thing. Cheats by using premade image.
    
    love.graphics.setCaption(love.timer.getFPS(), 0, 0)
end
function love.keypressed(key)
    if key == '1' and planet.name ~= 'mercury' then
        planet.tex = love.graphics.newImage('mercury.png')
        planet.name = 'mercury'
    elseif key == '2' and planet.name ~= 'venus' then
        planet.tex = love.graphics.newImage('venus.png')
        planet.name = 'venus'
    elseif key == '3' and planet.name ~= 'earth' then
        planet.tex = love.graphics.newImage('earth.png')
        planet.name = 'earth'
    elseif key == '4' and planet.name ~= 'mars' then
        planet.tex = love.graphics.newImage('mars.png')
        planet.name = 'mars'
    elseif key == '5' and planet.name ~= 'jupiter' then
        planet.tex = love.graphics.newImage('jupiter.png')
        planet.name = 'jupiter'
    elseif key == '6' and planet.name ~= 'saturn' then
        planet.tex = love.graphics.newImage('saturn.png')
        planet.name = 'saturn'
    elseif key == '7' and planet.name ~= 'uranus' then
        planet.tex = love.graphics.newImage('uranus.png')
        planet.name = 'uranus'
    elseif key == '8' and planet.name ~= 'neptune' then
        planet.tex = love.graphics.newImage('neptune.png')
        planet.name = 'neptune'
    elseif key == '9' and planet.name ~= 'moon' then
        planet.tex = love.graphics.newImage('moon.png')
        planet.name = 'moon'
    end
end